------
Sentry
------

Sentry provides you with a generic interface to view and interact with your error logs. By
default, it will catch any exception thrown by Django and store it in a database. With this
it allows you to interact and view near real-time information to discover issues and more
easily trace them in your application.


Docs: http://readthedocs.org/docs/sentry/en/latest/index.html